@@ -1,6 +1,7 @@
 package Apache2::AuthCASSimple;
 
 use strict;
+use warnings;
 use Apache2::Const qw( OK AUTH_REQUIRED DECLINED REDIRECT SERVER_ERROR M_GET);
 use Apache2::RequestUtil ();
 use Apache2::RequestRec ();
@@ -10,7 +11,7 @@ use Authen::CAS::Client;
 use Apache2::Connection;
 use vars qw($VERSION);
 
-$VERSION = '0.0.4';
+$VERSION = '0.06';
 
 
 #
@@ -127,9 +128,9 @@ sub handler ($) {
 sub _get_requested_url ($$) {
   my $r = shift;
   my $mod_proxy = shift;
+  my $is_https = $r->dir_config('HTTPSServer') || 0;
 
   my $port = $r->get_server_port();
-  my $is_https = $r->subprocess_env('https') ? 1 : 0;
 
   my $url = $is_https ? 'https://' : 'http://';
   $url .= $r->hostname();
@@ -208,6 +209,7 @@ sub _get_user_from_session ($) {
   my $cas_session_dir = $r->dir_config('CASSessionDirectory') || '/tmp';
   my $cas_cookie_path = $r->dir_config('CASFixDirectory') || '/';
   my $cas_session_timeout = $r->dir_config('CASSessionTimeout') || 60;
+  my $is_https = $r->dir_config('HTTPSServer') || 0;
 
   $r->log()->info(__PACKAGE__.": Checking session.");
 
@@ -216,7 +218,7 @@ sub _get_user_from_session ($) {
         directory => $cas_session_dir,
         lock_directory  => $cas_session_dir,
         use_cookie => 1,
-        cookie_secure => $r->subprocess_env('https') ? 1 : 0,
+        cookie_secure => $is_https,
         cookie_resend => 1,
         cookie_expires => 'session',
         cookie_path => $cas_cookie_path
@@ -261,6 +263,7 @@ sub _create_user_session ($) {
   my $mod_proxy = $r->dir_config('ModProxy');
   my $cas_session_dir = $r->dir_config('CASSessionDirectory') || '/tmp';
   my $cas_cookie_path = $r->dir_config('CASFixDirectory') || '/';
+  my $is_https = $r->dir_config('HTTPSServer') || 0;
 
   $r->log()->info(__PACKAGE__.": Creating session");
 
@@ -269,7 +272,7 @@ sub _create_user_session ($) {
         directory => $cas_session_dir,
         lock_directory  => $cas_session_dir,
         use_cookie => 1,
-        cookie_secure => $r->subprocess_env('https') ? 1 : 0,
+        cookie_secure => $is_https,
         cookie_resend => 1,
         cookie_expires => 'session',
         cookie_path => $cas_cookie_path
@@ -317,6 +320,7 @@ This module allow the use of simple text files for sessions.
     PerlSetVar CASSessionDirectory /tmp
     # PerlSetVar CASFixDirectory /
     # PerlSetVar ModProxy 1
+    # PerlSetVar HTTPSServer 1
 
     require valid-user
   </Location>
@@ -378,6 +382,14 @@ Force the path of the session cookie for same policy in all subdirectories else
 
 Apache2 mod_perl2 don't be use with mod_proxy. Default is off.
 
+=item HTTPSServer
+
+If you want to keep a HTTPS server for all data. Default is 0.
+
+=item OK AUTH_REQUIRED DECLINED REDIRECT SERVER_ERROR M_GET
+
+Apache constants to make pod coverage happy
+
 =back
 
 =head1 METHOD
@@ -388,14 +400,14 @@ call by apache2
 
 =head1 VERSION
 
-This documentation describes Apache2::AuthCASSimple version 0.0.1
+This documentation describes Apache2::AuthCASSimple version 0.06
 
 =head1 BUGS AND TROUBLESHOOTING
 
 =over 4
 
 =item *
-Old expired sessions files must be deleted with an external provided script : C<delete_session_data.pl>
+Old expired sessions files must be deleted with an example provided script : C<delete_session_data.pl>
 
 =item *
 L<Apache::Session::Wrapper> certainly need L<Apache2::Cookie>
@@ -410,8 +422,14 @@ in your virtualhost conf
 =item *
 Apreq module must be enable in debian
 
+  a2enmod apreq
+
+or add 
+
   LoadModule apreq_module /usr/lib/apache2/modules/mod_apreq2.so
 
+in your apache configuration file
+
 =back
 
 Please submit any bug reports to agostini@univ-metz.fr.
@@ -432,6 +450,8 @@ Requires L<Apache::Session::Wrapper>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2008 by Yves Agostini
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
